//      ParserFactory.cxx
//
//      Copyright 2011 Andreas Tscharner <andy@vis.ethz.ch>
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU Lesser General Public License as
//      published by the Free Software Foundation; either version 3 of the
//      License, or (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU Lesser General Public
//      License along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.


#include <cstring>
#include <cstdio>
#include "ParserFactory.hxx"
#include "RCParser.hxx"
#include "RIFParser.hxx"
#include "../Utils.hxx"


#define BUF_SIZE 1024
#define RIF_STRING "<Resources"


InFileParser* ParserFactory::create_input_parser(const char *p_filename)
{
	char *fileExt;
	unsigned char buf[BUF_SIZE];
	FILE *inFile;
	int readBytes;


	if (!file_exists(p_filename)) {
		return nullptr;
	};

	fileExt = get_extension((char *)p_filename);
	if (strcmp(fileExt, ".rc") == 0) {
		return new RCParser((char *)p_filename);
	};
	if (strcmp(fileExt, ".rif") == 0) {
		return new RIFParser((char *)p_filename);
	};

	inFile = fopen(p_filename, "r");
	if (!inFile) {
		return nullptr;
	};
	readBytes = fread(buf, sizeof(unsigned char), BUF_SIZE, inFile);
	fclose(inFile);

	if (strstr((const char *)buf, RIF_STRING)) {
		return new RIFParser((char *)p_filename);
	} else {
		return new RCParser((char *)p_filename);
	};
}
