//      ParserFactory.hxx
//
//      Copyright 2011, 2014 Andreas Tscharner <andy@vis.ethz.ch>
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU Lesser General Public License as
//      published by the Free Software Foundation; either version 3 of the
//      License, or (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU Lesser General Public
//      License along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.


/*! \file ParserFactory.hxx
 *
 * This file contains the declaration of the ParserFactory class that is
 * used to create a matching parser class depending on the file to parse.
 *
 * \author Andreas Tscharner
 * \date 2014-08-23
 */


#ifndef __PARSERFACTORY_HXX__
#define __PARSERFACTORY_HXX__


// Include files
#include "InFileParser.hxx"


/*! \class ParserFactory
 *  \brief Factory class to create an appropriate parser class
 *
 * This factory class is used to create a parser class that is able to parse
 * a given input file. There are two possibilities: Parsing a .rc file or
 * parsing a .rif file (xml).
 */
class ParserFactory
{
	public:
		/*! \brief Creates an appropiate parser class
		 *
		 * This method creates a parser class depending on the given file.
		 * The file can be a .rc or a .rif (xml) file
		 *
		 * \param[in] p_filename Name of the file to parse
		 *
		 * \return Instance of a macthing parser class
		 *
		 * \remarks The caller is responsible to free/delete the returned
		 *          class
		 * \remarks If the file does not exist \c nullptr will be returned
		 */
		static InFileParser *create_input_parser(const char *p_filename);
};


#endif /* __PARSERFACTORY_HXX__ */
