//      ShowEmbeddedImage.cxx
//
//      Copyright 2014 Andreas Tscharner <andy@vis.ethz.ch>
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU Lesser General Public License as
//      published by the Free Software Foundation; either version 3 of the
//      License, or (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU Lesser General Public
//      License along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.


#include <iostream>
#include <SDL/SDL.h>
#include <SDL/SDL_image.h>
#include "../include/ResourceManager.hxx"

extern "C" {
	extern unsigned char _binary_EmbeddedLogos_rdf_start;
	extern unsigned char _binary_EmbeddedLogos_rdf_end;
};

using namespace lrc;

void deleteList(char **p_dataList, int p_dataSize)
{
	for (int i = (p_dataSize-1); i>=0; i--)
		delete[] p_dataList[i];
	delete[] p_dataList;
}

int main(int argc, char **argv)
{
	const int WINDOW_WIDTH = 640;
	const int WINDOW_HEIGHT = 480;

	ResourceManager *logos;
	Resource *logoRes;
	lrc::CompressionType comprType;
	char **logosList;
	int numLogos;
	SDL_Surface *mainScreen, *logoSurf;
	SDL_RWops *logoImg;
	SDL_Rect logoWin;


	logos = new ResourceManager(
	  &_binary_EmbeddedLogos_rdf_start,
	  &_binary_EmbeddedLogos_rdf_end,
	  lrc::NoneCompression,
	  lrc::NoneEncryption,
	  nullptr);

	logosList = logos->get_resource_ids(numLogos);
	if (numLogos < 1) {
		std::cout << "No entries found" << std::endl;
		delete logos;
		return -1;
	};

	if (SDL_Init(SDL_INIT_VIDEO) < 0) {
		std::cout << "Could not initialize SDL: ";
		std::cout << SDL_GetError() << std::endl;
		deleteList(logosList, numLogos);
		delete logos;
		return -1;
	};

	mainScreen = SDL_SetVideoMode(WINDOW_WIDTH, WINDOW_HEIGHT, 0, SDL_HWPALETTE|SDL_DOUBLEBUF);
	if (mainScreen == NULL) {
		std::cout << "Could not set windowed video mode to " << WINDOW_WIDTH << "x" << WINDOW_HEIGHT << ": ";
		std::cout << SDL_GetError() << std::endl;
		deleteList(logosList, numLogos);
		delete logos;
		return -1;
	};
	SDL_WM_SetCaption("Embedded example", NULL);

	for (int i=0; i<numLogos; i++) {
		if (i !=  (numLogos-1)) {
			logoRes = logos->get_resource(logosList[i]);
		} else {
			logoRes = logos->get_resource(logosList[i], (const unsigned char *)"MySecretPassword");
		};
		logoImg = SDL_RWFromMem(logoRes->get_res_data(), logoRes->get_res_size());
		logoSurf = IMG_LoadPNG_RW(logoImg);
		SDL_FreeRW(logoImg);

		logoWin.x = (WINDOW_WIDTH / 2) - (logoSurf->w / 2);
		logoWin.y = (WINDOW_HEIGHT /2) - (logoSurf->h / 2);
		logoWin.w = logoSurf->w;
		logoWin.h = logoSurf->h;

		SDL_BlitSurface(logoSurf, NULL, mainScreen, &logoWin);
		SDL_Flip(mainScreen);

		SDL_Delay(2000);

		SDL_FreeSurface(logoSurf);

		SDL_FillRect(mainScreen, &logoWin, 0);

		delete logoRes;
	};
	delete logos;

	SDL_Quit();

	return 0;
}

