//      lrcExceptions.cxx
//
//      Copyright 2011, 2012 Andreas Tscharner <andy@vis.ethz.ch>
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU Lesser General Public License as
//      published by the Free Software Foundation; either version 3 of the
//      License, or (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU Lesser General Public
//      License along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.


#include <string>
#include <cstring>
#include "lrcExceptions.hxx"


lrcFileNotFoundException::lrcFileNotFoundException(char *p_fileNotFoundName)
{
	size_t len;


	len = strlen(p_fileNotFoundName)+1;
	m_fileNotFound = new char[len];
	memset(m_fileNotFound, 0, len);
	strncpy(m_fileNotFound, p_fileNotFoundName, (len-1));
}

lrcFileNotFoundException::~lrcFileNotFoundException(void) throw()
{
	delete[] m_fileNotFound;
}

const char *lrcFileNotFoundException::what(void) const throw()
{
	std::string retStr;


	retStr = "\"";
	retStr += m_fileNotFound;
	retStr += "\" could not be found.";
	return retStr.c_str();
}


lrcFileExistsException::lrcFileExistsException(char *p_filename)
{
	size_t len;


	len = strlen(p_filename) + 1;
	m_fileOverwrite = new char[len];
	memset(m_fileOverwrite, 0, len);
	strncpy(m_fileOverwrite, p_filename, (len-1));
}

lrcFileExistsException::~lrcFileExistsException(void) throw()
{
	delete[] m_fileOverwrite;
}

const char *lrcFileExistsException::what(void) const throw()
{
	std::string retStr;


	retStr = "\"";
	retStr += m_fileOverwrite;
	retStr += "\" should be overwritten, but overwriting is not allowed.";
	return retStr.c_str();
}


lrcEncryptionDisabledException::lrcEncryptionDisabledException(char *p_resourceID)
{
	size_t reqStrLen;


	reqStrLen = strlen(p_resourceID) + 1;
	m_resourceID = new char[reqStrLen];
	memset(m_resourceID, 0, reqStrLen);
	strncpy(m_resourceID, p_resourceID, (reqStrLen-1));
}

lrcEncryptionDisabledException::~lrcEncryptionDisabledException(void) throw()
{
	delete[] m_resourceID;
}

const char *lrcEncryptionDisabledException::what(void) const throw()
{
	std::string retStr;


	retStr = "The resource \"";
	retStr += m_resourceID;
	retStr += "\" requires encryption, but the compiler was built without it.";
	return retStr.c_str();
}
