//      NoneCompression.hxx
//
//      Copyright 2011 Andreas Tscharner <andy@vis.ethz.ch>
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU Lesser General Public License as
//      published by the Free Software Foundation; either version 3 of the
//      License, or (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU Lesser General Public
//      License along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.


/*! \file NoneCompression.hxx
 *
 * This file contains the class declaration of the NoneCompression class.
 * This class is a dummy class that does no compression at all, but is used
 * to fit in the Strategy Pattern
 *
 * \author Andreas Tscharner
 * \date 2011-06-25
 */


#ifndef __NONECOMPRESSION_HXX__
#define __NONECOMPRESSION_HXX__


#include "../include/CompressDecompress.hxx"


/*! \class NoneCompression
 *  \brief Compression class that does \em NO compression
 *
 * This class does no compression at all. It is used for the simplest case
 * of no compression. It is created and implemented nonetheless to fit in
 * the Strategy Pattern
 */
class NoneCompression : public lrc::CompressDecompress
{
	public:
		/*! \brief No compression
		 *
		 * This method does no compression and returns a copy of the given
		 * data.
		 */
		int compress(const unsigned char *, size_t, unsigned char **, size_t &);
		/*! \brief No decompression
		 *
		 * Thos method does no decompression and returns a copy of the given
		 * data
		 */
		int decompress(const unsigned char *, size_t, unsigned char **, size_t &);
};


#endif /* __NONECOMPRESSION_HXX__ */
