//      bz2LibCompression.hxx
//
//      Copyright 2012 Andreas Tscharner <andy@vis.ethz.ch>
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU Lesser General Public License as
//      published by the Free Software Foundation; either version 3 of the
//      License, or (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU Lesser General Public
//      License along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.


/*! \file bz2LibCompression.hxx
 *
 * This file contains the declaration of the bz2Lib compression class. This
 * class is used to compress and decompress teh resource data using the bzip2
 * algorithm.
 *
 * \author Andreas Tscharner
 * \date 2012-01-18
 */


#ifndef __BZ2LIBCOMPRESSION_HXX__
#define __BZ2LIBCOMPRESSION_HXX__


#include "../include/CompressDecompress.hxx"

/*! \class bz2LibCompression
 *
 * \brief Compression class that uses the \em bzip2 algorithm
 *
 * This class uses the bzip2 algorithm for compression and decompression of
 * the resource data.
 */
class bz2LibCompression : public lrc::CompressDecompress
{
	public:
		/*! \brief bzip2 compression
		 *
		 * This method compresses the given data using the bzip2 algorithm
		 */
		int compress(const unsigned char *, size_t, unsigned char **, size_t &);
		/*! \brief bzip2 decompression
		 *
		 * This method decompresses the given data using the bzip2 algorithm
		 */
		int decompress(const unsigned char *, size_t, unsigned char **, size_t &);
};


#endif /* __BZ2LIBCOMPRESSION_HXX__ */
